==> solist-2.0.zip: listener/QuitListener.java <==
package listener;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;
import java.util.Collection;

import javax.swing.JOptionPane;

import editor.SolistEditor;

import model.ClassManager;
import model.Play;
import model.TheaterClass;
import util.ResourceManager;

/**
 * Listener Beenden von Theater
 * 
 * @author Dietrich Boles, Uni Oldenburg
 * @version 1.0 (12.11.2008)
 * 
 */
public class QuitListener implements ActionListener {

	public void actionPerformed(ActionEvent e) {
		QuitListener.quit();
	}

	public static void quit() {
		Play play = Play.getPlay();
		if (!play.isEmpty()) {
			play.save();

			try {
				play.getInfoEditor().save();
			} catch (IOException exc) {
				exc.printStackTrace();
			}

			try {
				SolistEditor.getSolistEditor().save();
			} catch (IOException exc) {
				if (!play.isSimulator()) {
					exc.printStackTrace();
				}
			}

			boolean allSaved = true;
			String files = "";
			Collection<TheaterClass> coll = ClassManager.getClassManager()
					.getAllClasses();
			for (TheaterClass cls : coll) {
				if (!cls.getEditor().isSaved()) {
					allSaved = false;
					if (!files.equals("")) {
						files = files + ", ";
					}
					files = files + cls.getName() + ".java";
				}
			}
			files = files + ".";

			if (!allSaved) {
				int n = JOptionPane.showConfirmDialog(play.getPlayFrame(),
						ResourceManager.getResourceManager().getValue(
								"msg.saverequest1")
								+ "\n"
								+ files
								+ "\n"
								+ ResourceManager.getResourceManager()
										.getValue("msg.saverequest2"),
						ResourceManager.getResourceManager().getValue(
								"msg.request"),
						JOptionPane.YES_NO_CANCEL_OPTION);
				if (n == JOptionPane.YES_OPTION) {

					Collection<TheaterClass> cls = ClassManager
							.getClassManager().getAllClasses();
					for (TheaterClass c : cls) {
						try {
							c.getEditor().save();
						} catch (IOException exc) {
							exc.printStackTrace();
						}
					}

				} else if (n == JOptionPane.NO_OPTION) {
					// nothing
				} else {
					return;
				}

			}
		}
		System.exit(0);
	}

}

==> solist-2.1.zip: listener/QuitListener.java <==
package listener;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.io.IOException;
import java.util.Collection;

import javax.swing.JOptionPane;

import model.ClassManager;
import model.Play;
import model.TheaterClass;
import scratch.ScratchFile;
import scratch.ScratchProgram;
import util.PropertyManager;
import util.ResourceManager;
import editor.SolistEditor;

/**
 * Listener Beenden von Theater
 * 
 * @author Dietrich Boles, Uni Oldenburg
 * @version 1.0 (12.11.2008)
 * 
 */
public class QuitListener implements ActionListener {

	public void actionPerformed(ActionEvent e) {
		QuitListener.quit();
	}

	public static void quit() {
		Play play = Play.getPlay();
		if (!play.isEmpty()) {
			play.save();

			try {
				play.getInfoEditor().save();
			} catch (IOException exc) {
				exc.printStackTrace();
			}

			try {
				SolistEditor.getSolistEditor().save(false);
			} catch (IOException exc) {
				if (!play.isSimulator()) {
					exc.printStackTrace();
				}
			}

			if (Play.getPlay().isSimulator()
					&& PropertyManager.getPropertyManager().isScratch()) {
				String fileName = Play.getPlay().getDirectory()
						+ File.separatorChar
						+ ScratchFile.SCRATCH_FILENAME;
				ScratchProgram program = Play.getPlay().getPlayFrame().getScratchPanel().getProgram();
				ScratchFile.saveProgram(program, fileName);
			}

			boolean allSaved = true;
			String files = "";
			Collection<TheaterClass> coll = ClassManager.getClassManager()
					.getAllClasses();
			for (TheaterClass cls : coll) {
				if (!cls.getEditor().isSaved()) {
					allSaved = false;
					if (!files.equals("")) {
						files = files + ", ";
					}
					files = files + cls.getName() + ".java";
				}
			}
			files = files + ".";

			if (!allSaved) {
				int n = JOptionPane.showConfirmDialog(play.getPlayFrame(),
						ResourceManager.getResourceManager().getValue(
								"msg.saverequest1")
								+ "\n"
								+ files
								+ "\n"
								+ ResourceManager.getResourceManager()
										.getValue("msg.saverequest2"),
						ResourceManager.getResourceManager().getValue(
								"msg.request"),
						JOptionPane.YES_NO_CANCEL_OPTION);
				if (n == JOptionPane.YES_OPTION) {

					Collection<TheaterClass> cls = ClassManager
							.getClassManager().getAllClasses();
					for (TheaterClass c : cls) {
						try {
							c.getEditor().save();
						} catch (IOException exc) {
							exc.printStackTrace();
						}
					}

				} else if (n == JOptionPane.NO_OPTION) {
					// nothing
				} else {
					return;
				}

			}
		}
		System.exit(0);
	}

}
